# 🚀 Paiement par CinetPay 👋
[![MIT License](https://img.shields.io/apm/l/atomic-design-ui.svg?)](https://github.com/tterb/atomic-design-ui/blob/master/LICENSEs)
[![CinetPay Logo](https://imgur.com/WxqeWOL.png)](https://cinetpay.com)

> Ce package vous permet d'invoquer le **guichet de paiement de CinetPay**, effectuer un paiement et attendre le statut du paiement initié à la seconde près après la fin du paiement

## 🔗 Les étapes
L'utilisation du package est la plus simple possible, dans son utilisation, il s'agit d'invoquer celui-ci avec :
- `Les paramétres d'initialisation du guichet`
- `Les données relatives au paiement`
- `Le callback d'attente du retour de paiement`
- `Le callback d'écoute d'erreur d'exécution`

## 🛠 Les prérequis
Quelques prérequis sont nécessaires pour faire fonctionner correctement le package.

 - #### Android

    - Ajouter les permissions suivantes dans le fichier **_android/app/src/main/AndroidManifest.xml_** 
    
        ```xml
            <application
            	...
                android:usesCleartextTraffic="true">
                ...
            </application>
            ...
            <uses-permission android:name="android.permission.INTERNET"/>
        ```
    - Modifier la version du **_minSdkVersion_** dans le fichier **_android/app/src/build.gradle** 
        > `minSdkVersion 17`
        
 - #### IOS
   - Ajouter la permission suivante dans le fichier **_ios/Runner/Info.plist_**
   
        ```plist
            <key>NSAppTransportSecurity</key>
            <dict>
                <key>NSAllowsArbitraryLoads</key>
                <true/>
            </dict>
        ```

## Initialisation du guichet
Pour fonctionner, le guichet doit impérativement recevoir des données telles que :

- _**apikey**_ | L’identifiant du marchand | Chaine de caractère | `Obligatoire`
- _**site_id**_ | L'identifiant du service | Entier | `Obligatoire`
- _**notify_url**_ | URL de notification de paiement valide | URL | `Obligatoire`

## Données du paiement
Pour effectuer le paiement, certaines données devront-être sousmises pour préparer le guichet. Ainsi, on a :

- _**amount**_ | Montant du paiement `(>= 100 XOF)` | Entier | `Obligatoire`
- _**currency**_ | Devise du paiement (`XOF` - `XAF` - `CDN` - `GNF` - `USD`) | Chaîne de caractère | `Obligatoire`
- _**transaction_id**_ | L'identifiant de la transaction. Elle doit-être unique, pour chaque transaction | Chaîne de caractère | `Obligatoire`
- _**description**_ | La description de votre paiement | Chaîne de caractère | `Obligatoire`
- _**channels**_ | L’univers de paiement. Peut être : `ALL` - `MOBILE_MONEY` - `CREDIT_CARD` - `WALLET`. Par défaut : `'ALL'`  Toute combinaison est applicable à en séparant par une virgule : `'MOBILE_MONEY, WALLET'` | Chaîne de caractère | Facultatif
- _**metadata**_ |  | Chaîne de caractère | Facultatif
- _**customer_name**_ | Nom de l’acheteur `*` | Chaîne de caractère | Facultatif
- _**customer_surname**_ | Prénoms de l’acheteur `*` | Chaîne de caractère | Facultatif
- _**customer_email**_ | Adresse email de l’acheteur `*` | Chaîne de caractère | Facultatif
- _**customer_phone_number**_ | Numéro de téléphone de l’acheteur `*` | Chaîne de caractère
- _**customer_city**_ | Ville de l’acheteur `*` | Chaîne de caractère | Facultatif
- _**customer_country**_ | Pays de l’acheteur. Code ISO2 du pays (CI => Côte-d'Ivoire). `*` | Chaîne de caractère | Facultatif
- _**customer_state**_ | Etat de l’acheteur (Lorsque USA est utilisé comme pays) `*` | Chaîne de caractère | Facultatif
- _**customer_zip_code**_ | Code postal de l’acheteur `*` | Chaîne de caractère | Facultatif
 > **NB** : `*` Obligatoire si utilisation de l’univers bancaire (CREDIT_CARD)

## Callback de retour de paiement
Lorsque le paiement est enclenché, le package reste en attente du statut final du paiement-ci. Ainsi, à la fin du paiement le package reçoit le statut, qu'il le transmet au travers du callback qui sera définit. Le format de retour attendu est le suivant :

- _**amount**_ | Montant du paiement | Entier
- _**currency**_ | Devise du paiement | Chaîne de caractère
- _**status**_ | Statut du paiement (`ACCEPTED` ou `REFUSED)` | Chaîne de caractère
- _**payment_method**_ | Moyen du paiement | Chaîne de caractère
- _**description**_ | La description de votre paiement | Chaîne de caractère
- _**metadata**_ | Chaîne de caractère
- _**operator_id**_ | L'identifiant du paiement de l'opérateur | Chaîne de caractère
- _**payment_date**_ | La date du paiement | Chaîne de caractère

## Callback d'erreur de traitement
Lors du traitement, il peut survenir certains types d'erreurs telles que, _certains paramètres pour le paiement manquantes_. Le format de retour attendu est le suivant :

- _**message**_ | Chaîne de caractère
- _**description**_ | Chaîne de caractère

## 👩‍💻 Utilisation du package
En resumé, le package s'utilise par le biais d'un appel appel widget :
```dart
CinetPayCheckout(
    title: 'Guichet de paiement',
    configData: <String, dynamic> {
        'apikey': 'YOUR_API_KEY',
        'site_id': YOUR_SITE_ID,
        'notify_url': 'https://mondomaine.com/notify/'
    },
    paymentData: <String, dynamic> {
        'transaction_id': 'YOUR_TRANSACTION_ID',
        'amount': 100,
        'currency': 'XOF',
        'channels': 'ALL',
        'description': 'Test de paiement'
    },
    waitResponse: (response) {
        print(response);
    }
    onError: (error) {
        print(error);
    }
);
```

![CinetPay Checkout](http://cdn.cinetpay.com/img/cinetpay-checkout.png)

## 😄 Auteur
Agbetogor Germain ([@Germinator](https://cinetpay.com))